@@ -215,6 +215,14 @@ class NHLRoster(Roster):
     }
 
 
+class F1ShowdownRoster(Roster):
+    POSITION_ORDER = {
+        'CPT': 0,
+        'D': 1,
+        'CNSTR': 2,
+    }
+
+
 class RosterSelect:
     @staticmethod
     def roster_gen(league):
@@ -237,6 +245,7 @@ class RosterSelect:
             'XFL': NFLRoster(),
             'TEN': TenRoster(),
             'CSGO_SHOWDOWN': ShowdownRoster(),
+            'F1_SHOWDOWN': F1ShowdownRoster(),
         }
         return roster_dict[league]
 
